==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectMapply_ternary.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectmapply_ternary_h
#define objectmapply_ternary_h
#include <admsObject/admsH.h>
#include <admsObject/objectSubexpression.h>
typedef enum {
  adms_mapply_ternary_enumeration_name_conditional
} e_mapply_ternary_name;
win32_interface char* adms_mapply_ternary_tostring_name_impl (p_admsttransform myadmsttransform,e_mapply_ternary_name e);
win32_interface e_mapply_ternary_name adms_mapply_ternary_fromstring_name_impl (p_admsttransform myadmsttransform,char*token);
struct s_mapply_ternary {
  t_subexpression _subexpression;
  e_mapply_ternary_name _name;
  int _name_isdefault : 1;
  gpointer _arg1;
  int _arg1_isdefault : 1;
  gpointer _arg2;
  int _arg2_isdefault : 1;
  gpointer _arg3;
  int _arg3_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_mapply_ternary_getuid (p_mapply_ternary mymapply_ternary);
win32_interface gboolean adms_mapply_ternary_cmp (p_mapply_ternary mymapply_ternary,p_mapply_ternary refmapply_ternary);
win32_interface p_mapply_ternary adms_mapply_ternary_new_1 (e_mapply_ternary_name myname,gpointer myarg1,gpointer myarg2,gpointer myarg3);
#define adms_mapply_ternary_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_mapply_ternary_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_mapply_ternary_new_impl (p_adms arguments[]);
win32_interface p_mapply_ternary adms_mapply_ternary_impl (void* member);
#define adms_mapply_ternary(member) ((p_mapply_ternary) (member))
#define adms_mapply_ternary_new adms_mapply_ternary_new_1
#define adms_mapply_ternary_isdefault_name(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_name_isdefault)
#define adms_mapply_ternary_valueof_name(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_name)
#define adms_mapply_ternary_isdefault_arg1(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg1_isdefault)
#define adms_mapply_ternary_valueof_arg1(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg1)
#define adms_mapply_ternary_isdefault_arg2(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg2_isdefault)
#define adms_mapply_ternary_valueof_arg2(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg2)
#define adms_mapply_ternary_isdefault_arg3(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg3_isdefault)
#define adms_mapply_ternary_valueof_arg3(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg3)
#define adms_mapply_ternary_valueof_subexpression(mapply_ternary) ((p_subexpression)mapply_ternary)
#define adms_mapply_ternary_valueof_math(mapply_ternary) ((p_math)mapply_ternary)
#define adms_mapply_ternary_valueof_adms(mapply_ternary) ((p_adms)mapply_ternary)
#define adms_mapply_ternary_valueto_name(a,b) ((p_mapply_ternary)a)->_name=(b)
win32_interface void adms_mapply_ternary_valueto_name_impl (p_mapply_ternary mymapply_ternary,e_mapply_ternary_name _name);
#define adms_mapply_ternary_valueto_arg1(a,b) ((p_mapply_ternary)a)->_arg1=(b)
win32_interface void adms_mapply_ternary_valueto_arg1_impl (p_mapply_ternary mymapply_ternary,gpointer _arg1);
#define adms_mapply_ternary_valueto_arg2(a,b) ((p_mapply_ternary)a)->_arg2=(b)
win32_interface void adms_mapply_ternary_valueto_arg2_impl (p_mapply_ternary mymapply_ternary,gpointer _arg2);
#define adms_mapply_ternary_valueto_arg3(a,b) ((p_mapply_ternary)a)->_arg3=(b)
win32_interface void adms_mapply_ternary_valueto_arg3_impl (p_mapply_ternary mymapply_ternary,gpointer _arg3);
#endif /* objectmapply_ternary_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectMapply_ternary.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectmapply_ternary_h
#define objectmapply_ternary_h
#include <admsObject/admsH.h>
#include <admsObject/objectSubexpression.h>
typedef enum {
  adms_mapply_ternary_enumeration_name_conditional
} e_mapply_ternary_name;
win32_interface char* adms_mapply_ternary_tostring_name_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_mapply_ternary_name adms_mapply_ternary_fromstring_name_impl (p_admsttransform myadmsttransform,char*token);
struct s_mapply_ternary {
  t_subexpression _subexpression;
  p_enumeration _name;
  int _name_isdefault : 1;
  p_adms _arg1;
  int _arg1_isdefault : 1;
  p_adms _arg2;
  int _arg2_isdefault : 1;
  p_adms _arg3;
  int _arg3_isdefault : 1;
};
#include <admsObject/objectEnumeration.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_mapply_ternary_uid (p_mapply_ternary mymapply_ternary);
win32_interface int adms_mapply_ternary_cmp (p_mapply_ternary mymapply_ternary,p_mapply_ternary refmapply_ternary);
win32_interface p_mapply_ternary adms_mapply_ternary_new(p_enumeration myname,p_adms myarg1,p_adms myarg2,p_adms myarg3);
win32_interface p_adms adms_mapply_ternary_new_impl (p_adms arguments[]);
#define adms_mapply_ternary(member) ((p_mapply_ternary) (member))
#define adms_mapply_ternary_isdefault_name(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_name_isdefault)
#define adms_mapply_ternary_valueof_name(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_name)
#define adms_mapply_ternary_isdefault_arg1(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg1_isdefault)
#define adms_mapply_ternary_valueof_arg1(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg1)
#define adms_mapply_ternary_isdefault_arg2(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg2_isdefault)
#define adms_mapply_ternary_valueof_arg2(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg2)
#define adms_mapply_ternary_isdefault_arg3(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg3_isdefault)
#define adms_mapply_ternary_valueof_arg3(mapply_ternary) (adms_mapply_ternary(mapply_ternary)->_arg3)
#define adms_mapply_ternary_valueof_subexpression(mapply_ternary) ((p_subexpression)mapply_ternary)
#define adms_mapply_ternary_valueof_math(mapply_ternary) ((p_math)mapply_ternary)
#define adms_mapply_ternary_valueof_adms(mapply_ternary) ((p_adms)mapply_ternary)
win32_interface inline void adms_mapply_ternary_valueto_name (p_mapply_ternary mymapply_ternary,p_enumeration _name);
win32_interface inline void adms_mapply_ternary_valueto_arg1 (p_mapply_ternary mymapply_ternary,p_adms _arg1);
win32_interface inline void adms_mapply_ternary_valueto_arg2 (p_mapply_ternary mymapply_ternary,p_adms _arg2);
win32_interface inline void adms_mapply_ternary_valueto_arg3 (p_mapply_ternary mymapply_ternary,p_adms _arg3);
win32_interface inline void adms_mapply_ternary_free(p_mapply_ternary mymapply_ternary);
#endif /* objectmapply_ternary_h */
